@@ -2,11 +2,16 @@ import eventlet
 from flask import Flask
 from flask_socketio import SocketIO, send
 
+app = Flask(__name__, static_url_path='/')
+
+@app.route('/')
+def index():
+    return app.send_static_file('index.html')
+
 def serve(args):
     eventlet.monkey_patch()
     print('Starting websocket server...')
-
-    app = Flask(__name__, static_folder='/zincbase/web/static')
+    
     socketio = SocketIO(app, message_queue=f"redis://{args.redis}", cors_allowed_origins='*')
 
     @socketio.on('message')
@@ -17,4 +22,5 @@ def serve(args):
     def handle_connect():
         pass
 
-    socketio.run(app)
\ No newline at end of file
+    socketio.run(app)
+    return app
\ No newline at end of file
